@@ -1,15 +1,9 @@
 #ifndef _CHAMPLAIN_PERL_H_
 
-#include <clutterperl.h>
-
+#include <clutter-perl.h>
 
 #include <champlain/champlain.h>
 
-#ifdef CHAMPLAINPERL_GTK
-#include <champlain-gtk/champlain-gtk.h>
-#endif
-
-
 #include "champlain-autogen.h"
 
 #endif /* _CHAMPLAIN_PERL_H_ */
